==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_contact.js <==
_me = frm_contact.prototype;
function frm_contact(){};

_me.__constructor = function() {
	this._draw('frm_contact', 'main');
	this.__initForm('CONTACT::CONTACT');
};

_me.__loadItems = function() {
	if (!this.maintab) return;
	var me = this;
	var oTabs = this.maintab;

	// parsing Locations
	if (Is.Defined(this._aValues['LOCATIONS'])) {
		var aLocation;
		var aLocations = this._aValues['LOCATIONS'];

		for (var i in aLocations) {
			aLocation = aLocations[i];

			switch (aLocation['values']['LCTTYPE']) {
				case 'H': this._sHomeLocation = aLocation; break;
				case 'O': this._sOtherLocation = aLocation; break;
				case 'B': this._sBusinessLocation = aLocation; break;
			}
			if (aLocation['values']['LCT_ID'])
				aLocation['uid'] = i;
		}
	}

	// TAB1
	loadDataIntoForm(oTabs.tab1,this._aValues);

	//Copy contact name into window title
	oTabs.tab1.ITMCLASSIFYAS._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
			    sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
		    me._title('CONTACT::CONTACT');
	};
	oTabs.tab1.ITMCLASSIFYAS._onkeyup();

	if (Is.Defined(this._sHomeLocation)) {
		if (Is.Defined(this._sHomeLocation['values']['LCTEMAIL1']))
			oTabs.tab1.X_EMAIL1._value(this._sHomeLocation['values']['LCTEMAIL1']);
		if (Is.Defined(this._sHomeLocation['values']['LCTEMAIL2']))
			oTabs.tab1.X_EMAIL2._value(this._sHomeLocation['values']['LCTEMAIL2']);
		if (Is.Defined(this._sHomeLocation['values']['LCTEMAIL3']))
			oTabs.tab1.X_EMAIL3._value(this._sHomeLocation['values']['LCTEMAIL3']);

		var j = 1;

		for (var nPhone in this._sHomeLocation['PHONES']) {
			oTabs.tab1['X_PHONE'+j]._value(this._sHomeLocation['PHONES'][nPhone]);
			if (j++ >= 4) break;
		}
	}
	//Default Phone type values
	else{
		oTabs.tab1['X_PHONE1']._value({values:{PHNTYPE:'D'}});
		oTabs.tab1['X_PHONE2']._value({values:{PHNTYPE:'A'}});
		oTabs.tab1['X_PHONE3']._value({values:{PHNTYPE:'G'}});
		oTabs.tab1['X_PHONE4']._value({values:{PHNTYPE:'L'}});
	}

	if (!this._aValues['ITM_ID'])
		oTabs.tab1.ITMSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','contact_sharing'));

	// TAB2
	oTabs.tab2._onactive = function (bFirstTime) {
		if (bFirstTime) {
			loadDataIntoForm(this,me._aValues);
			if (Is.Defined(me._sHomeLocation)) {
				this.X_HOME_ADDRESS._value(me._sHomeLocation);
				if (Is.Defined(me._sHomeLocation['values']['LCTWEBPAGE']))
					this.X_HOMEPAGE._value(me._sHomeLocation['values']['LCTWEBPAGE']);
			}
			if (Is.Defined(me._sOtherLocation))
				this.X_OTHER_ADDRESS._value(me._sOtherLocation);
		}
	}
	
	// TAB3
	oTabs.tab3._onactive = function (bFirstTime) {
		if (bFirstTime) {
			loadDataIntoForm(this,me._aValues);
			if (Is.Defined(me._sBusinessLocation)) {
				this.X_OFFICE_ADDRESS._value(me._sBusinessLocation);
				if (Is.Defined(me._sBusinessLocation['values']['LCTWEBPAGE']))
					this.X_WEB._value(me._sBusinessLocation['values']['LCTWEBPAGE']);
			}
		}
	}			
		
	// TAB4
	oTabs.tab4._onactive = function (bFirstTime) {
		if (bFirstTime) {
			loadDataIntoForm(this,me._aValues);
			if (Is.Defined(me._aValues['CERTIFICATES']))
				this.X_CERTIFICATE._value(me._aValues['CERTIFICATES'][0]['values']['CERTIFICATE']);
		}
	}
	
	// TAB5
	oTabs.tab5._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['ATTACHMENTS']))
			this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
		else
		if (me._aValues['PUSH_ATTACHMENTS'])
			this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
	}

	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab5._active();
}

_me.__saveItems = function(aValues) {
	var tab1 = this.maintab.tab1;
	var tab2 = this.maintab.tab2;
	var tab3 = this.maintab.tab3;
	var tab4 = this.maintab.tab4;
	var tab5 = this.maintab.tab5;
	var aHome;
	var aOther;
	var aBusiness;
	
	if (Is.Defined(tab2.X_HOME_ADDRESS)) {
		aHome = tab2.X_HOME_ADDRESS._value();
		aOther = tab2.X_OTHER_ADDRESS._value();
		aHome['values']['LCTWEBPAGE'] = tab2.X_HOMEPAGE._value();
	} else {
		if (Is.Defined(this._sHomeLocation))
			aHome = this._sHomeLocation;
		else
			aHome = {'values':{}};
			
		if (Is.Defined(this._sOtherLocation))
			aOther = this._sOtherLocation;
		else
			aOther = {'values':{}};
	}
	
	if (Is.Defined(tab3.X_OFFICE_ADDRESS)) {
		aBusiness = tab3.X_OFFICE_ADDRESS._value();
		aBusiness['values']['LCTWEBPAGE'] = tab3.X_WEB._value();
	} else {
		aBusiness = {'values':{}};
	}
	
	aHome['values']['LCTEMAIL1'] = tab1.X_EMAIL1._value();
	aHome['values']['LCTEMAIL2'] = tab1.X_EMAIL2._value();
	aHome['values']['LCTEMAIL3'] = tab1.X_EMAIL3._value();

	var aPhones = [];
	var aPhone;
	if (!Is.Empty(aPhone = tab1['X_PHONE1']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhone = tab1['X_PHONE2']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhone = tab1['X_PHONE3']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhone = tab1['X_PHONE4']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhones)) 
		aHome['PHONES'] = aPhones;
	
	var aLocations = [];
	if (!isFormEmpty(aHome)) {
		aHome['values']['LCTTYPE'] = 'H';
		aLocations.push(aHome);
	}
	if (!isFormEmpty(aBusiness)) {
		aBusiness['values']['LCTTYPE'] = 'B';
		aLocations.push(aBusiness);
	}
	if (!isFormEmpty(aOther)) {
		aOther['values']['LCTTYPE'] = 'O';
		aLocations.push(aOther);
	}
	if (aLocations.length) 
		aValues['LOCATIONS'] = aLocations;
	
	var aAttachments;
	if (tab5.X_ATTACHMENTS && !Is.Empty(aAttachments = tab5.X_ATTACHMENTS._value())) 
		aValues['ATTACHMENTS'] = aAttachments;
		
	if (tab4.X_CERTIFICATE)
		aValues['CERTIFICATES'] = [{'values':{'CERTIFICATE':tab4.X_CERTIFICATE._value()}}];
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_contact.js <==
_me = frm_contact.prototype;
function frm_contact(){};

_me.__constructor = function() {
	this._draw('frm_contact', 'main');
	this.__initForm('CONTACT::CONTACT');
};

_me.__loadItems = function() {
	if (!this.maintab) return;
	var me = this;
	var oTabs = this.maintab;

	// parsing Locations
	if (Is.Defined(this._aValues['LOCATIONS'])) {
		var aLocation;
		var aLocations = this._aValues['LOCATIONS'];

		for (var i in aLocations) {
			aLocation = aLocations[i];

			switch (aLocation['values']['LCTTYPE']) {
				case 'H': this._sHomeLocation = aLocation; break;
				case 'O': this._sOtherLocation = aLocation; break;
				case 'B': this._sBusinessLocation = aLocation; break;
			}
			if (aLocation['values']['LCT_ID'])
				aLocation['uid'] = i;
		}
	}

	// TAB1
	loadDataIntoForm(oTabs.tab1,this._aValues);

	//Copy contact name into window title
	oTabs.tab1.ITMCLASSIFYAS._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
			    sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
		    me._title('CONTACT::CONTACT');
	};
	oTabs.tab1.ITMCLASSIFYAS._onkeyup();

	if (Is.Defined(this._sHomeLocation)) {
		if (Is.Defined(this._sHomeLocation['values']['LCTEMAIL1']))
			oTabs.tab1.X_EMAIL1._value(this._sHomeLocation['values']['LCTEMAIL1']);
		if (Is.Defined(this._sHomeLocation['values']['LCTEMAIL2']))
			oTabs.tab1.X_EMAIL2._value(this._sHomeLocation['values']['LCTEMAIL2']);
		if (Is.Defined(this._sHomeLocation['values']['LCTEMAIL3']))
			oTabs.tab1.X_EMAIL3._value(this._sHomeLocation['values']['LCTEMAIL3']);

		var j = 1;

		for (var nPhone in this._sHomeLocation['PHONES']) {
			oTabs.tab1['X_PHONE'+j]._value(this._sHomeLocation['PHONES'][nPhone]);
			if (j++ >= 4) break;
		}
	}
	//Default Phone type values
	else{
		oTabs.tab1['X_PHONE1']._value({values:{PHNTYPE:'D'}});
		oTabs.tab1['X_PHONE2']._value({values:{PHNTYPE:'A'}});
		oTabs.tab1['X_PHONE3']._value({values:{PHNTYPE:'G'}});
		oTabs.tab1['X_PHONE4']._value({values:{PHNTYPE:'L'}});
	}

	if (!this._aValues['ITM_ID'])
		oTabs.tab1.ITMSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','contact_sharing'));

	// TAB2
	oTabs.tab2._onactive = function (bFirstTime) {
		if (bFirstTime) {
			loadDataIntoForm(this,me._aValues);
			if (Is.Defined(me._sHomeLocation)) {
				this.X_HOME_ADDRESS._value(me._sHomeLocation);
				if (Is.Defined(me._sHomeLocation['values']['LCTWEBPAGE']))
					this.X_HOMEPAGE._value(me._sHomeLocation['values']['LCTWEBPAGE']);
			}
			if (Is.Defined(me._sOtherLocation))
				this.X_OTHER_ADDRESS._value(me._sOtherLocation);
		}
	}
	
	// TAB3
	oTabs.tab3._onactive = function (bFirstTime) {
		if (bFirstTime) {
			loadDataIntoForm(this,me._aValues);
			if (Is.Defined(me._sBusinessLocation)) {
				this.X_OFFICE_ADDRESS._value(me._sBusinessLocation);
				if (Is.Defined(me._sBusinessLocation['values']['LCTWEBPAGE']))
					this.X_WEB._value(me._sBusinessLocation['values']['LCTWEBPAGE']);
			}
		}
	}			
		
	// TAB4
	oTabs.tab4._onactive = function (bFirstTime) {
		if (bFirstTime) {
			loadDataIntoForm(this,me._aValues);
			if (Is.Defined(me._aValues['CERTIFICATES']))
				this.X_CERTIFICATE._value(me._aValues['CERTIFICATES'][0]['values']['CERTIFICATE']);
		}
	}
	
	// TAB5
	oTabs.tab5._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['ATTACHMENTS']))
			this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
		else
		if (me._aValues['PUSH_ATTACHMENTS'])
			this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
	}

	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab5._active();
}

_me.__saveItems = function(aValues) {

	//autofill classify as
	if (!aValues.values.ITMCLASSIFYAS){
        aValues.values.ITMCLASSIFYAS  = aValues.values.ITMSURNAME || '';
		aValues.values.ITMCLASSIFYAS += (aValues.values.ITMCLASSIFYAS?' ':'') + (aValues.values.ITMFIRSTNAME || '');
        if (!aValues.values.ITMCLASSIFYAS && aValues.values.ITMNICKNAME)
            aValues.values.ITMCLASSIFYAS = aValues.values.ITMNICKNAME;
    }

	var tab1 = this.maintab.tab1;
	var tab2 = this.maintab.tab2;
	var tab3 = this.maintab.tab3;
	var tab4 = this.maintab.tab4;
	var tab5 = this.maintab.tab5;
	var aHome;
	var aOther;
	var aBusiness;

	if (Is.Defined(tab2.X_HOME_ADDRESS)) {
		aHome = tab2.X_HOME_ADDRESS._value();
		aOther = tab2.X_OTHER_ADDRESS._value();
		aHome['values']['LCTWEBPAGE'] = tab2.X_HOMEPAGE._value();
	}
	else {
		if (Is.Defined(this._sHomeLocation))
			aHome = this._sHomeLocation;
		else
			aHome = {'values':{}};
			
		if (Is.Defined(this._sOtherLocation))
			aOther = this._sOtherLocation;
		else
			aOther = {'values':{}};
	}
	
	if (Is.Defined(tab3.X_OFFICE_ADDRESS)) {
		aBusiness = tab3.X_OFFICE_ADDRESS._value();
		aBusiness['values']['LCTWEBPAGE'] = tab3.X_WEB._value();
	}
	else{
		if (Is.Defined(this._sBusinessLocation))
			aBusiness = this._sBusinessLocation;
		else
			aBusiness = {'values':{}};
	}
	
	aHome['values']['LCTEMAIL1'] = tab1.X_EMAIL1._value();
	aHome['values']['LCTEMAIL2'] = tab1.X_EMAIL2._value();
	aHome['values']['LCTEMAIL3'] = tab1.X_EMAIL3._value();

	var aPhones = [];
	var aPhone,aKeys = [];
	if (!Is.Empty(aPhone = tab1['X_PHONE1']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhone = tab1['X_PHONE2']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhone = tab1['X_PHONE3']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhone = tab1['X_PHONE4']._value())) aPhones.push(aPhone);
	if (!Is.Empty(aPhones)){
		aHome['PHONES'] = aPhones;
		for(var k in aPhones)
		    aKeys.push(k);
	}

	var aLocations = [], bIsHome = false;
	if (!isFormEmpty(aHome)) {
		aHome['values']['LCTTYPE'] = 'H';
		aLocations.push(aHome);
		bIsHome = true;
	}

	if (!isFormEmpty(aBusiness)) {
		if (aHome['PHONES'] && aBusiness['PHONES']){
			var k = 0;
			for(var i in aBusiness['PHONES']){
                if (aBusiness['PHONES'][i].values.PHN_ID)
                	aBusiness['PHONES'][i].uid = aBusiness['PHONES'][i].values.PHN_ID;

				if (aKeys.length>k && aHome['PHONES'][aKeys[k]].values){
					aBusiness['PHONES'][i].values.PHNTYPE = aHome['PHONES'][aKeys[k]].values.PHNTYPE;
                    aBusiness['PHONES'][i].values.PHNNUMBER = aHome['PHONES'][aKeys[k]].values.PHNNUMBER;
                    aBusiness['PHONES'][i].values.PHNDESCRIPTION = aHome['PHONES'][aKeys[k]].values.PHNDESCRIPTION;
				}
				else
				if (aBusiness['PHONES'][i].values)
					delete aBusiness['PHONES'][i].values;

				k++;
			}
		}
		else
		    delete aBusiness['PHONES'];

		// add location
		aBusiness['values']['LCTTYPE'] = 'B';
		aLocations.push(aBusiness);
	}

	if (!isFormEmpty(aOther)) {
		if (aHome['PHONES'] && aOther['PHONES']){
			var k = 0;
			for(var i in aOther['PHONES']){

				if (aOther['PHONES'][i].values.PHN_ID)
                	aOther['PHONES'][i].uid = aOther['PHONES'][i].values.PHN_ID;

				if (aKeys.length>k && aHome['PHONES'][aKeys[k]].values){
					aOther['PHONES'][i].values.PHNTYPE = aHome['PHONES'][aKeys[k]].values.PHNTYPE;
                    aOther['PHONES'][i].values.PHNNUMBER = aHome['PHONES'][aKeys[k]].values.PHNNUMBER;
                    aOther['PHONES'][i].values.PHNDESCRIPTION = aHome['PHONES'][aKeys[k]].values.PHNDESCRIPTION;
				}
				else
				if (aOther['PHONES'][i].values)
					delete aOther['PHONES'][i].values;

				k++;
			}
		}
		else
		    delete aOther['PHONES'];
		    
		// add location
		aOther['values']['LCTTYPE'] = 'O';
		aLocations.push(aOther);
	}

	if (aLocations.length){

		// add HOME location if doesnt exist
		if (!bIsHome)
			aLocations.push({values:{LCTTYPE:'H'}});

		aValues['LOCATIONS'] = aLocations;
	}
	
	var aAttachments;
	if (tab5.X_ATTACHMENTS && !Is.Empty(aAttachments = tab5.X_ATTACHMENTS._value())) 
		aValues['ATTACHMENTS'] = aAttachments;
		
	if (tab4.X_CERTIFICATE)
		aValues['CERTIFICATES'] = [{'values':{'CERTIFICATE':tab4.X_CERTIFICATE._value()}}];
};
